@@ -27,7 +27,10 @@ class TitofistoStorage(FileSystemStorage):
     def get_token(self, name: str, ts: Optional[str] = None) -> tuple[str, str]:
         """Get a token and associated generation timestamp for a filename."""
         # Determine parts of the HMAC from the file
-        mtime = self.get_modified_time(name).isoformat()
+        if self.exists(name):
+            mtime = self.get_modified_time(name).isoformat()
+        else:
+            mtime = datetime.now().isoformat()
         if ts is None:
             ts = datetime.now().strftime("%s")
         full_msg = f"{name}//{mtime}@{ts}"
